import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "qrScanPaymentForm"

    Context.context.logoActionInfo: () => this.logoAction()

    function logoAction() {
        if (cancelButton.visible)
            return
        let callAttendant = Action.create("AUTH_CALLATTENDANT", { showCancel: true })
        callAttendant.success.connect((action) => { cancelButton.visible = true })
        PluginManager.async(callAttendant)
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: 20
        SGroupBox {
            Layout.fillHeight: true
            Layout.fillWidth: true
            ColumnLayout {
                anchors.horizontalCenter: parent.horizontalCenter
                y: 300
                spacing: 0
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "qrScanPaymentTitle"
                    Tr { code: "qrScanPaymentTitle" }
                }
                RowLayout {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.topMargin: 5
                    spacing: 7
                    visible: !Check.paymentAction.amount.zero
                    SLabel {
                        Layout.alignment: Qt.AlignHCenter
                        Style.class: "qrScanPaymentTitle"
                        Tr { code: "qrScanPaymentDue" }
                    }
                    SMoney {
                        Style.class: "qrScanPaymentTitle"
                        money: Check.paymentAction.amount
                        color: styleColor
                    }
                }
                Space { height: 40 }
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "qrScanPaymentMsg"
                    Tr { code: "qrScanPaymentMsg" }
                }
                Space { height: 200 }
                SvgImage {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 350
                    Layout.preferredHeight: 350
                    Qr { id: qr; size: 350; data: Check.paymentAction.data }
                    source: qr.image
                }
                Space { height: 80 }
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "qrScanPaymentTimeout"
                    Tr { id: tr; code: "qrScanPaymentTimeout" }
                    Timer {
                        property int secondsLeft: Check.paymentAction.timeout
                        onSecondsLeftChanged: tr.args = [ secondsLeft ]
                        interval: 1000
                        running: secondsLeft > 0
                        triggeredOnStart: true
                        repeat: true
                        onTriggered: --secondsLeft
                    }
                }
            }
        }
        ActionButton {
            id: cancelButton
            Layout.preferredHeight: 110
            Layout.fillWidth: true
            visible: Config.getBool("Check:showPaymentQrCancel", true)
            Tr { code: "qrPaymentCancel" }
            Style.class: "qrPaymentCancel"
            icon: Style.parameter("icon.payment.closeQrScanPaymentForm")
            onClicked: () => root.removeContext()
        }
    }
}
